pub type IPerceptionFrameProvider = *mut ::core::ffi::c_void;
pub type IPerceptionFrameProviderManager = *mut ::core::ffi::c_void;
pub type PerceptionControlGroup = *mut ::core::ffi::c_void;
pub type PerceptionCorrelation = *mut ::core::ffi::c_void;
pub type PerceptionCorrelationGroup = *mut ::core::ffi::c_void;
pub type PerceptionFaceAuthenticationGroup = *mut ::core::ffi::c_void;
pub type PerceptionFrame = *mut ::core::ffi::c_void;
pub type PerceptionFrameProviderInfo = *mut ::core::ffi::c_void;
pub type PerceptionPropertyChangeRequest = *mut ::core::ffi::c_void;
pub type PerceptionStartFaceAuthenticationHandler = *mut ::core::ffi::c_void;
pub type PerceptionStopFaceAuthenticationHandler = *mut ::core::ffi::c_void;
pub type PerceptionVideoFrameAllocator = *mut ::core::ffi::c_void;
