pub type IAnnotationProvider = *mut ::core::ffi::c_void;
pub type ICustomNavigationProvider = *mut ::core::ffi::c_void;
pub type IDockProvider = *mut ::core::ffi::c_void;
pub type IDragProvider = *mut ::core::ffi::c_void;
pub type IDropTargetProvider = *mut ::core::ffi::c_void;
pub type IExpandCollapseProvider = *mut ::core::ffi::c_void;
pub type IGridItemProvider = *mut ::core::ffi::c_void;
pub type IGridProvider = *mut ::core::ffi::c_void;
pub type IInvokeProvider = *mut ::core::ffi::c_void;
pub type IItemContainerProvider = *mut ::core::ffi::c_void;
pub type IMultipleViewProvider = *mut ::core::ffi::c_void;
pub type IObjectModelProvider = *mut ::core::ffi::c_void;
pub type IRangeValueProvider = *mut ::core::ffi::c_void;
pub type IRawElementProviderSimple = *mut ::core::ffi::c_void;
pub type IScrollItemProvider = *mut ::core::ffi::c_void;
pub type IScrollProvider = *mut ::core::ffi::c_void;
pub type ISelectionItemProvider = *mut ::core::ffi::c_void;
pub type ISelectionProvider = *mut ::core::ffi::c_void;
pub type ISpreadsheetItemProvider = *mut ::core::ffi::c_void;
pub type ISpreadsheetProvider = *mut ::core::ffi::c_void;
pub type IStylesProvider = *mut ::core::ffi::c_void;
pub type ISynchronizedInputProvider = *mut ::core::ffi::c_void;
pub type ITableItemProvider = *mut ::core::ffi::c_void;
pub type ITableProvider = *mut ::core::ffi::c_void;
pub type ITextChildProvider = *mut ::core::ffi::c_void;
pub type ITextEditProvider = *mut ::core::ffi::c_void;
pub type ITextProvider = *mut ::core::ffi::c_void;
pub type ITextProvider2 = *mut ::core::ffi::c_void;
pub type ITextRangeProvider = *mut ::core::ffi::c_void;
pub type ITextRangeProvider2 = *mut ::core::ffi::c_void;
pub type IToggleProvider = *mut ::core::ffi::c_void;
pub type ITransformProvider = *mut ::core::ffi::c_void;
pub type ITransformProvider2 = *mut ::core::ffi::c_void;
pub type IValueProvider = *mut ::core::ffi::c_void;
pub type IVirtualizedItemProvider = *mut ::core::ffi::c_void;
pub type IWindowProvider = *mut ::core::ffi::c_void;
