pub type ContactDataProviderConnection = *mut ::core::ffi::c_void;
pub type ContactDataProviderTriggerDetails = *mut ::core::ffi::c_void;
pub type ContactListCreateOrUpdateContactRequest = *mut ::core::ffi::c_void;
pub type ContactListCreateOrUpdateContactRequestEventArgs = *mut ::core::ffi::c_void;
pub type ContactListDeleteContactRequest = *mut ::core::ffi::c_void;
pub type ContactListDeleteContactRequestEventArgs = *mut ::core::ffi::c_void;
pub type ContactListServerSearchReadBatchRequest = *mut ::core::ffi::c_void;
pub type ContactListServerSearchReadBatchRequestEventArgs = *mut ::core::ffi::c_void;
pub type ContactListSyncManagerSyncRequest = *mut ::core::ffi::c_void;
pub type ContactListSyncManagerSyncRequestEventArgs = *mut ::core::ffi::c_void;
